ZealError

Enum ZealError 

pub enum ZealError {
Show 15 variants NetworkError { source: Error, retryable: bool, }, WebSocketError { message: String, }, JsonError { source: Error, }, ConfigurationError { message: String, }, ApiError { status: u16, message: String, error_code: Option<String>, }, NotFound { resource: String, id: String, }, ValidationError { field: String, message: String, }, AuthenticationError { message: String, }, RateLimitError { message: String, retry_after: Option<Duration>, }, TimeoutError { operation: String, }, ConnectionError { message: String, }, SerializationError { source: Box<dyn Error + Send + Sync>, }, InvalidUrl { source: ParseError, }, IoError { source: Error, }, Other { message: String, },
}
Main error type for the Zeal SDK

Variants



NetworkError

Network-related errors

Fields

source: Error
retryable: bool


WebSocketError

WebSocket-related errors

Fields

message: String


JsonError

JSON parsing errors

Fields

source: Error


ConfigurationError

Invalid configuration

Fields

message: String


ApiError

API errors from the server

Fields

status: u16
message: String
error_code: Option<String>


NotFound

Resource not found

Fields

resource: String


ValidationError

Validation errors

Fields

field: String
message: String


AuthenticationError

Authentication/authorization errors

Fields

message: String


RateLimitError

Rate limiting errors

Fields

message: String
retry_after: Option<Duration>


TimeoutError

Timeout errors

Fields

operation: String


ConnectionError

Connection errors

Fields

message: String


SerializationError

Serialization errors

Fields

source: Box<dyn Error + Send + Sync>


InvalidUrl

URL parsing errors

Fields

source: ParseError


IoError

I/O errors

Fields

source: Error


Other

Generic errors

Fields

message: String

Implementations

Source

impl ZealError

pub fn network_error(source: Error) -> Self

Create a network error

pub fn websocket_error<S: Into<String>>(message: S) -> Self

Create a WebSocket error

pub fn configuration_error<S: Into<String>>(message: S) -> Self

Create a configuration error

pub fn api_error( status: u16, message: String, error_code: Option<String>, ) -> Self

Create an API error

pub fn not_found<S: Into<String>>(resource: S, id: S) -> Self

Create a not found error

pub fn validation_error<S: Into<String>>(field: S, message: S) -> Self

Create a validation error

pub fn authentication_error<S: Into<String>>(message: S) -> Self

Create an authentication error

pub fn rate_limit_error<S: Into<String>>( message: S, retry_after: Option<Duration>, ) -> Self

Create a rate limit error

pub fn timeout_error<S: Into<String>>(operation: S) -> Self

Create a timeout error

pub fn connection_error<S: Into<String>>(message: S) -> Self

Create a connection error

pub fn other<S: Into<String>>(message: S) -> Self

Create a generic error

pub fn is_retryable(&self) -> bool

Check if the error is retryable

pub fn retry_after(&self) -> Option<Duration>

Get the retry delay if applicable

pub fn is_client_error(&self) -> bool

Check if the error is a client error (4xx)

pub fn is_server_error(&self) -> bool

Check if the error is a server error (5xx)